@@ -1,17 +1,16 @@
-import prql_python as prql
 import json
 
+import prql_python as prql
+
 
 def test_all():
     """
     Test the basic python functions
     """
 
-    # Since the AST is so in flux lets just take these dont throw exceptions
-    print(dir(prql))
-    dir(prql)
-    print(prql)
     prql_query = "from employee"
+
+    # Since the AST is so in flux lets just take these dont throw exceptions
     res = json.loads(prql.to_json(prql_query))
     assert res is not None
 
@@ -19,5 +18,5 @@ def test_all():
     assert res is not None
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     test_all()
